<html>
    <head>
        <title>SageMath</title>
        <link rel="stylesheet" href="/sagenb/www/sagenb-export.css"/>
        <script type="text/javascript" src="/sagenb/www/sagenb-export.js"></script>
    </head>
    <body>
        <div class="header">
            <h1>Sage Mathematics Software</h1>
            <img src="/sagenb/www/sagemath_icon.svg">
        </div>

        <div class="old">
            <h2>Use the Jupyter notebook.</h2>
            <p><a class="button" href="/tree" >Take me to the Jupyter notebook</a></p>
            <p>
                To skip this page and go directly to the Jupyter notebook, run
                <tt>sage --notebook=jupyter</tt>
                on the command line.
            </p>
            <h2>The old notebook is now deprecated.</h2>
            <p>
                Starting from version 9.0, Sage is using Python3 by default.
                The old Sage notebook only works for Sage using Python2 and is now deprecated.
                The old Sage notebook is still available as an optional package, working only under Python2. You need to install it using <tt>sage -i sagenb</tt>.
            <p>
            <p><a class="button" href="/sagenb/www/run-sagenb.html">Run the old Sage Notebook</a></p>
            <p>
                To skip this page and launch directly the old notebook, run
                <tt>sage --notebook=sagenb</tt>
                on the command line.
            </p>
        </div>

        <div class="old">
            <h2>Convert old notebooks to Jupyter</h2>
            <p>Click on any of the notebooks below to convert it to a new Jupyter notebook and open it in Jupyter:</p>
        </div>

        <div class="error">
        </div>
        
        <div class="nb-list">
            <div class="nb-row nb-header">
                <div class="nb-id">ID</div>
                <div class="nb-name">Name</div>
            </div>
            {% for nb in notebooks %}
            <div class="nb-row clickable" onclick="exportSageNB('{{nb.unique_id}}')">
                <div class="nb-id"><span class="ellipsis">{{ nb.unique_id }}</span></div>
                <div class="nb-name"><span class="ellipsis">{{ nb.name }}</span></div>
            </div>
            {% endfor %}
        </div>
        
    </body>
</html>

